import requests
from bs4 import BeautifulSoup
import json
import os
from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.chrome.service import Service
from webdriver_manager.chrome import ChromeDriverManager
import time

def get_reviews_from_naver_cafe():
    service = Service(ChromeDriverManager().install())
    driver = webdriver.Chrome(service=service)

    # 네이버 카페 후기 페이지로 이동
    driver.get("https://cafe.naver.com/realcom7?iframe_url=/ArticleList.nhn%3Fsearch.clubid=29274663%26search.menuid=1%26search.boardtype=C")
    time.sleep(3)
    
    driver.switch_to.frame("cafe_main")
    time.sleep(2)
    
    reviews = []
    
    articles = driver.find_elements(By.CSS_SELECTOR, "div.board-list div.inner_list")
    for article in articles:
        title = article.find_element(By.CSS_SELECTOR, "a.article").text.strip()
        article_id = article.find_element(By.CSS_SELECTOR, "a.article").get_attribute("href").split("=")[-1]
        article.click()
        time.sleep(2)
        
        content = driver.find_element(By.ID, "tbody").text.strip()
        username = driver.find_element(By.CLASS_NAME, "nickname").text.strip()
        img_tags = driver.find_elements(By.CSS_SELECTOR, "div.se-module.se-module-image img")
        img_url = img_tags[0].get_attribute("src") if img_tags else None
        
        reviews.append({'id': article_id, 'title': title, 'content': content, 'username': username, 'img_url': img_url})
        
        driver.back()
        time.sleep(2)
        driver.switch_to.frame("cafe_main")
        time.sleep(2)

    driver.quit()
    return reviews

def save_reviews_to_file(reviews, filename):
    with open(filename, 'w', encoding='utf-8') as file:
        json.dump(reviews, file, ensure_ascii=False, indent=4)

def download_image(url, folder='images'):
    if not url:
        return None
    if not os.path.exists(folder):
        os.makedirs(folder)
    img_data = requests.get(url).content
    filename = os.path.join(folder, os.path.basename(url))
    with open(filename, 'wb') as handler:
        handler.write(img_data)
    return filename

def main():
    reviews = get_reviews_from_naver_cafe()

    # 기존에 처리된 리뷰 ID를 로드
    if os.path.exists('processed_reviews.json'):
        with open('processed_reviews.json', 'r', encoding='utf-8') as file:
            processed_reviews = json.load(file)
    else:
        processed_reviews = []

    # 새로운 리뷰만 필터링
    new_reviews = [review for review in reviews if review['id'] not in processed_reviews]

    # 이미지 다운로드 및 저장 경로 추가
    for review in new_reviews:
        img_path = download_image(review['img_url'])
        review['img_path'] = img_path

    # 새로운 리뷰 저장
    filename = 'reviews.json'
    save_reviews_to_file(new_reviews, filename)

    # 처리된 리뷰 ID 업데이트
    processed_reviews.extend([review['id'] for review in new_reviews])
    with open('processed_reviews.json', 'w', encoding='utf-8') as file:
        json.dump(processed_reviews, file, ensure_ascii=False, indent=4)

if __name__ == "__main__":
    main()
